#!/bin/bash
VER="1.0"
####------------------------------------------------------------####
# PreSetup 1.0 by Turranius ( http://www.grandis.nu/glftpd/ )      #
####                                                            ####
# Do you hate setting up the pre folders for new affils with       #
# all the symlinks left and right etc? If so, read on.             #
# This script will make the pre folder, set up the symlink and     #
# change chmod and chown ( permissions and owner of the folder ).  #
# It will also tell you what you should set up in glftpd.conf so   #
# the folder is hidden from any other users.                       #
# It will NOT edit glftpd.conf. I know we all how our own way of   #
# how it should look in there, so it will only give some advice    #
# that you can cut and paste.                                      #
#                                                                  #
# It will only create 1 section folder at a time, so if you have a #
# group with multiple sections, run it once for each section.      #
#                                                                  #
# I planned on putting in some advice for different pre scripts    #
# but seeing how many there are, I think I'll skip that. I only    #
# know how f00-pre works anyway. Might include that one in future  #
# versions. Send me your config file for other pre scripts and I   #
# might be able to implement something for them.                   #
#                                                                  #
# Since most pre scripts want to have the pre folder on the same   #
# partition as the folder they are preeing to, this script is      #
# mostly geared for that setup.                                    #
# The default setup is:                                            #
# Your generic pre folder, where all the groups have their         #
# symlinks, is called GROUPS, and resides in /glftpd/site/GROUPS.  #
# In there, a folder is created for each group, with a symlink to  #
# the actual pre folder. A shortcut folder for affils if you will. #
# Something like /glftpd/site/GROUPS/SMuT/XXX, where XXX is just   #
# a symlink to /glftpd/site/XXX/GROUPS/SMuT.                       #
# This folder is chmodded to 755 to make sure dumb affils does not #
# upload directly into it.                                         #
#                                                                  #
# The actual pre folders are located INSIDE the folder they are    #
# preeing to. Like /glftpd/site/XXX/GROUPS/SMuT. Only SMuT can see #
# that folder (Will recomend how to set that up in glftpd.conf).   #
#                                                                  #
# All of this can be changed of course. Just fiddle with the paths.#
# If you give the argument 'test', it will only show you what it   #
# is going to do. Use that during initial setup to make sure you   #
# got the paths right.                                             #
# When you run this script with no arguments, it will also check   #
# that all the paths exist and will show all sections you have     #
# defined.                                                         #
####                                                            #### 
# Installation:                                                    #
# Put the script anywhere you like. Make it executable.            #
# Edit it and set the options. Options are:                        #
#                                                                  #
# TEMPSTORAGE=      A folder where I can store some temp stuff in. #
# SITEROOT=         The path to your site folder.                  #
#                   Usually /glftpd/site                           #
# CHROOTEDSITEROOT= When setting up the symlink, I cant link it to #
#                   /glftpd/site/bla bla, so what does your site   #
#                   folder look like from glftpd's perspective?    #
#                   Usually just /site                             #
# GLCONFADVICE=     Do you want me to tell you what you should do  #
#                   in glftpd.conf? TRUE/FALSE                     #
#                   Will create a file in TEMPSTORAGE/newaffil.?   #
#                   and display it.                                # 
# QUICKADVICE=      The advice in the one above might be a bit too #
#                   lame for someone experienced in this.          #
#                   If this is true, it will just give you the one #
#                   privpaths for the created dir & a little more. #
#                   Only works if GLCONFADVICE is FALSE.           #
# CREATESYMLINKS=   Do you want symlinks created at all? TRUE/FALSE#
#                   If this is FALSE, only the actual pre folder   #
#                   is created.                                    #
# SYMLINKSPATH=     If the above is TRUE, what do you call / want  #
#                   to call the folder where the symlinks are      #
#                   located? Relative to SITEROOT.                 #
# PREFOLDERMODE=    What do we chmod the actual pre folder to?     #
#                   Recomend 777. Then you can mess with pers in   #
#                   glftpd.conf instead.                           #
#                   Set this to "" to fully disable it.            #
# PREFOLDEROWNER=   To whom do we chown the pre folder to?         #
#                   Open /glftpd/etc/passwd and look for the 3rd   #
#                   & 4th number (: separated). The 3rd number is  #
#                   the username, and the 4th is the group.        #
#                   The user glftpd has 0:0 as default.            #
#                   And that is also the default in this script.   #
#                   Set this to "" to fully disable it.            #         
# SYMFOLDERMODE=    What do we chmod the symlinks folder to?       #
#                   I prefer 755 so stupid affils cant accidently  #
#                   start uploading files here instead.            #
#                   Set this to "" to fully disable it.            #
# SYMFOLDEROWNER=   Whom do we chown the symlinks folder too.      #
#                   See PREFOLDEROWNER above.                      #
#                   Set this to "" to fully disable it.            #
# SLEEPTIME=        When you tell it to make a pre folder, it will #
#                   first show you what it is going to do. This is #
#                   the time you have to press Control-C before it #
#                   actually creates them. Set to 0 once you are   #
#                   confident enough.                              #
# SECTIONS=         The most important setting.                    #
#                   This is where you set the name of sections     #
#                   and where that sections pre folder should      #
#                   reside in. This is relative to SITEROOT, so    #
#                   in the default setup, if we want to create a   #
#                   pre folder in DIVX, it will be in              #
#                   /glftpd/site/DIVX/GROUPS/groupname.            #
#                                                                  #
#                   Each section has two settings. A name and path.#
#                   Separate the two with a ':' and separate       #
#                   sections with a space.                         #
#                   NameOfSection:LocationOfActaulPreFolder.       #
#                   The name is just used in this script and does  #
#                   not reflect the actual path.                   #
#                                                                  #
# Set up the above, then run it without any arguments and it will  #
# check if settings look correct, and tell you how you should use  #
# it. If you ever change anything, make sure to run it without     #
# arguments once so it can verify everything.                      #
###                                                             ####
# If it does not work for your setup for some reason, let me know  #
# and I'll try to fix it. It should work for everyone, but I'm     #
# sure I missed something. Give me some suggestions too!           #
# Contact Turranius/Turran/Turr|away/Turr|work on Efnet. (#glftpd) #
####------------------------------------------------------------####
# Settings:

TEMPSTORAGE=/glftpd/tmp  # Temp folder.
SITEROOT=/glftpd/site    # Full path to site folder.
CHROOTEDSITEROOT=/site   # as above, but without /glftpd (Yeah, I'm lazy, I know).
GLCONFADVICE=TRUE        # Noob advice.
QUICKADVICE=FALSE        # Just give me the quick version (GLCONFADVICE must be FALSE).

CREATESYMLINKS=TRUE      # Use symlinks?
SYMLINKPATH=GROUPS       # If above is TRUE, where are the symlinks, relative to SITEROOT.
                         # No slash in the beginning or end.
PREFOLDERMODE=777        # Pre folders will be chmod to this. Set to "" to disable.
PREFOLDEROWNER=0:0       # Pre folders will be chown to this. Set to "" to disable.
SYMFOLDERMODE=755        # Symlinks chmod, if CREATESYMLINKS is TRUE. Set to "" to disable.
SYMFOLDEROWNER=0:0       # Symlinks chown, if CREATESYMLINKS is TRUE. Set to "" to disable.
SLEEPTIME=10             # How long do you need to read what its going to do?

## Read about SECTIONS at the top. ##
## Remember, always run the script without arguments when you change SECTIONS. ##

SECTIONS="DIVX:DIVX/GROUPS APPS:ISO/APPS/GROUPS 0DAYS:0DAYS/GROUPS"


##########################################################################
# No change below here should be needed.                                 #
##########################################################################

if [ "$1" = "test" -o "$2" = "test" ]; then
  echo "# test is supposed to be the 3rd argument if you want to do a test run."
  exit 1
fi

if [ "$2" = "" ]; then
  echo "#------------------------------------------------#"
  echo "# Welcome to PreSetup $VER by Turranius.     "
  if [ "$2" = "" ]; then
    if [ "$1" != "" ];  then
      echo "# You have specified group $1, but no section."
      echo "# Usage: presetup.sh $1 SECTION               "
    fi
  fi
  if [ "$1" = "" ]; then
    echo "# You must specify a group and a section too."
    echo "# Usage: presetup.sh GROUP SECTION <test>"
  fi
  echo "#"
  echo "# If you use 'test' it wont actually do anything."
  echo "# "
  echo "#------------------------------------#"
  echo "# Available sections are:"

  for section in $SECTIONS; do
    SECTIONNAME="$( echo $section | awk -F":" '{print $1}' )"
    if [ "$SECTIONNAME" = "" ]; then
      echo "# Seems you have set up SECTIONS wrong."
      echo "# There is most likely a space with a : next to it."
      echo "# Check the README for how to set up sections."
      exit 1
    fi
    SECTIONPATH="$( echo $section | awk -F":" '{print $2}' )"
    if [ "$SECTIONPATH" = "" ]; then
      echo "# Error in SECTIONS. Make sure you defined them right."
      echo "# Section $SECTIONNAME is missing its path."
      exit 1
    fi
    if [ "$SECTIONPATH" = "" ]; then
      echo "Path for section $SECTIONNAME is wrong. Check the setup"
      exit 1
    fi
    SECTIONROOTPATH="$( echo $SECTIONPATH | awk -F"/" '{print $1}')"
    if [ -e $SITEROOT/$SECTIONROOTPATH ]; then 
      echo "# Name : $SECTIONNAME"
      echo "# (Path: $SITEROOT/$SECTIONPATH/ )"
    else
      echo "# $SITEROOT/$SECTIONROOTPATH does not exist."
      echo "# Sorry, but I do not set up the whole folder system for you."
      echo "# Either create the $SECTIONROOTPATH folder or check your SECTIONS setup in here."
      exit 1
    fi
    if [ "$CREATESYMLINKS" = "TRUE" ]; then
      if [ "$SYMLINKPATH" = "" ]; then
        echo "# You have symlinks creation on, but no SYMLINKPATH is set."
        echo "# Symlinks are either ON or OFF for all sections, so make"
        echo "# up your mind."
        exit 1
      else
        echo "# (SymL: $SITEROOT/$SYMLINKPATH/ )"
      fi
    fi
    echo "#------------------------------------#"
  done
  exit 0
fi

for each in $SECTIONS; do
  if [ "$SECTIONDATA" != "" ]; then
    MATCHVER="$( echo $each | awk -F":" '{print $1}')"
    if [ "$MATCHVER" = "$2" ]; then
      echo "Hmmm, you have two sections with the same name?"
      echo "Check your SECTIONS setup."
      exit 1
    fi
  fi

  MATCH="$( echo $each | awk -F":" '{print $1}')"
  if [ "$MATCH" = "$2" ]; then
    SECTIONDATA="$each"
  fi
done

if [ "$SECTIONDATA" = "" ]; then
  echo "The section $2 is not setup in SECTIONS. Check your settings or spelling."
  echo "Just run this script without any arguments to see setup sections."
  exit 0
fi

GROUPNAME="$1"
SECTION="$( echo $SECTIONDATA | awk -F":" '{print $1}')"
SECTIONPATH="$( echo $SECTIONDATA | awk -F":" '{print $2}')"

echo "###########################################################"
echo "# Welcome to PreSetup $VER by Turranius."
echo "#"
echo "# You have selected to create a pre folder for $GROUPNAME."
echo "# The folder will be created in: "
echo "# $SITEROOT/$SECTIONPATH/$GROUPNAME "
if [ "$PREFOLDERMODE" != "" ]; then
  echo "# (chmod $PREFOLDERMODE & chown $PREFOLDEROWNER )"
fi
echo "#"
if [ "$CREATESYMLINKS" = "TRUE" ]; then
  echo "# A symlink pointing there will be called: "
  echo "# $SITEROOT/$SYMLINKPATH/$GROUPNAME/$SECTION"
  if [ "$SYMFOLDERMODE" != "" ]; then
    echo "# (chmod $SYMFOLDERMODE & chown $SYMFOLDEROWNER )"
  fi
  echo "#"
else
  echo "# No symlinks will be made."
fi
if [ "$3" = "test" ]; then
  echo "# Test mode is enabled. Nothing will really be created."
fi
echo "# If that is not correct, press CTRL-C within $SLEEPTIME Seconds"
echo "###########################################################"

sleep $SLEEPTIME
if [ "$3" = "test" ]; then
  TST="(test)"
else
  TST=""
fi

if [ -e $SITEROOT/$SECTIONPATH ]; then
  echo "# Creating main pre area $SITEROOT/$SECTIONPATH/$GROUPNAME $TST"
  if [ -e $SITEROOT/$SECTIONPATH/$GROUPNAME ]; then
    echo "# $SITEROOT/$SECTIONPATH/$GROUPNAME already exists."
  else
    if [ "$3" != "test" ]; then
      mkdir $SITEROOT/$SECTIONPATH/$GROUPNAME
    fi
  fi
  if [ "$PREFOLDERMODE" != "" ]; then
    echo "# Setting chmod $PREFOLDERMODE on it. $TST"
    if [ "$3" != "test" ]; then
      chmod $PREFOLDERMODE $SITEROOT/$SECTIONPATH/$GROUPNAME
    fi
  fi
  if [ "$PREFOLDEROWNER" != "" ]; then
    echo "# Setting chown $PREFOLDEROWNER on it. $TST"
    if [ "$3" != "test" ]; then
      chown $PREFOLDEROWNER $SITEROOT/$SECTIONPATH/$GROUPNAME
    fi
  fi
else
  echo "# $SITEROOT/$SECTIONPATH does not exist. Creating it. $TST"
  if [ "$3" != "test" ]; then
    mkdir $SITEROOT/$SECTIONPATH
  fi
  if [ "$PREFOLDERMODE" != "" ]; then
    echo "# Setting chmod $PREFOLDERMODE on it. $TST"
    if [ "$3" != "test" ]; then
      chmod $PREFOLDERMODE $SITEROOT/$SECTIONPATH
    fi
  fi
  if [ "$PREFOLDEROWNER" != "" ]; then
    echo "# Setting chown $PREFOLDEROWNER on it. $TST"
    if [ "$3" != "test" ]; then
      chown $PREFOLDEROWNER $SITEROOT/$SECTIONPATH
    fi
  fi
  echo "# Creating main pre area $SITEROOT/$SECTIONPATH/$GROUPNAME $TST"
  if [ "$3" != "test" ]; then
    mkdir $SITEROOT/$SECTIONPATH/$GROUPNAME
  fi
  if [ "$PREFOLDERMODE" != "" ]; then
    echo "# Setting chmod $PREFOLDERMODE on it. $TST"
    if [ "$3" != "test" ]; then
      chmod $PREFOLDERMODE $SITEROOT/$SECTIONPATH/$GROUPNAME
    fi
  fi
  if [ "$PREFOLDEROWNER" != "" ]; then
    echo "# Setting chown $PREFOLDEROWNER on it. $TST"
    if [ "$3" != "test" ]; then
      chown $PREFOLDEROWNER $SITEROOT/$SECTIONPATH/$GROUPNAME
    fi
  fi
fi

sleep 1
## Symlinks folder creation.
if [ "$CREATESYMLINKS" = "TRUE" ]; then
  echo "#"
  echo "# Creating symlinks folder $TST"
  if [ -e $SITEROOT/$SYMLINKPATH ]; then
    if [ -e $SITEROOT/$SYMLINKPATH/$GROUPNAME ]; then
      echo "# $SITEROOT/$SYMLINKPATH/$GROUPNAME was already there."
      if [ "$SYMFOLDERMODE" != "" ]; then
        echo "# Oh well, setting chmod $SYMFOLDERMODE on it then. $TST"
        if [ "$3" != "test" ]; then
          chmod $SYMFOLDERMODE $SITEROOT/$SYMLINKPATH/$GROUPNAME
        fi
      fi
      if [ "$SYMFOLDEROWNER" != "" ]; then
        echo "# oh, and doing a chown $SYMFOLDEROWNER $TST"
        if [ "$3" != "test" ]; then
          chown $SYMFOLDEROWNER $SITEROOT/$SYMLINKPATH/$GROUPNAME
        fi
      fi
      if [ -e $SITEROOT/$SYMLINKPATH/$GROUPNAME/$SECTION ]; then
        echo "# $SITEROOT/$SYMLINKPATH/$GROUPNAME/$SECTION was already there."
      fi
    else
      if [ "$SYMFOLDERMODE" = "" ]; then
        echo "# Creating $SITEROOT/$SYMLINKPATH/$GROUPNAME. $TST"
        if [ "$3" != "test" ]; then
          mkdir $SITEROOT/$SYMLINKPATH/$GROUPNAME
        fi
      else 
        echo "# Creating $SITEROOT/$SYMLINKPATH/$GROUPNAME and setting chmod. $TST"
        if [ "$3" != "test" ]; then
          mkdir $SITEROOT/$SYMLINKPATH/$GROUPNAME
          chmod $SYMFOLDERMODE $SITEROOT/$SYMLINKPATH/$GROUPNAME
        fi
      fi
      if [ "$SYMFOLDEROWNER" != "" ]; then
        echo "# Setting owner to $SYMFOLDEROWNER $TST"
        if [ "$3" != "test" ]; then
          chown $SYMFOLDEROWNER $SITEROOT/$SYMLINKPATH/$GROUPNAME
        fi
      fi
    fi
  else
    echo "# Cant find the symlinks folder $SITEROOT/$SYMLINKPATH."
    echo "# Creating it. $TST"
    if [ "$3" != "test" ]; then
      mkdir $SITEROOT/$SYMLINKPATH
    fi
    if [ "$SYMFOLDERMODE" != "" ]; then
      echo "# Doing chmod $SYMFOLDERMODE on it. $TST"
      if [ "$3" != "test" ]; then
        chmod $SYMFOLDERMODE $SITEROOT/$SYMLINKPATH
      fi
    fi
    if [ "$SYMFOLDEROWNER" != "" ]; then
      echo "# Doing chown $SYMFOLDEROWNER on it. $TST"
      if [ "$3" != "test" ]; then
        chown $SYMFOLDEROWNER $SITEROOT/$SYMLINKPATH
      fi
    fi
    echo "# Creating $SITEROOT/$SYMLINKPATH/$GROUPNAME. $TST"
    if [ "$3" != "test" ]; then
      mkdir $SITEROOT/$SYMLINKPATH/$GROUPNAME
    fi 
    if [ "$SYMFOLDERMODE" != "" ]; then
      echo "# Doing chmod $SYMFOLDERMODE on it. $TST"
      if [ "$3" != "test" ]; then
        chmod $SYMFOLDERMODE $SITEROOT/$SYMLINKPATH/$GROUPNAME
      fi
    fi
    if [ "$SYMFOLDEROWNER" != "" ]; then
      echo "# Doing chown $SYMFOLDEROWNER on it. $TST"
      if [ "$3" != "test" ]; then
        chown $SYMFOLDEROWNER $SITEROOT/$SYMLINKPATH/$GROUPNAME
      fi
    fi
  fi

  echo "#"
  echo "# Making the actual symlink. $TST"
  echo "# Name : $SITEROOT/$SYMLINKPATH/$GROUPNAME/$SECTION"
  echo "# Point: $CHROOTEDSITEROOT/$SECTIONPATH/$GROUPNAME"

  if [ "$3" != "test" ]; then
      ln -d -s -f $CHROOTEDSITEROOT/$SECTIONPATH/$GROUPNAME $SITEROOT/$SYMLINKPATH/$GROUPNAME/$SECTION
  fi
fi  

#echo "###########################################################"
echo "#---------------------------------------------------------#"

if [ "$GLCONFADVICE" != "TRUE" ]; then
  if [ "$QUICKADVICE" = "TRUE" ]; then
    echo "# Here is your quick advice =)"
    echo "privpath $CHROOTEDSITEROOT/$SECTIONPATH/$GROUPNAME  =$GROUPNAME !*"
    if [ "$CREATESYMLINKS" = "TRUE" ]; then
      echo "privpath $CHROOTEDSITEROOT/$SYMLINKPATH/$GROUPNAME  =$GROUPNAME !*"
    fi
    echo ""
    echo "# Below only needed once for each section. Replace $2 with *"
    echo "# if your structure is the same in all sections."
    echo "hideinwho $CHROOTEDSITEROOT/$SECTIONPATH/*  *"
    echo "creditloss 0 yes $CHROOTEDSITEROOT/$SECTIONPATH/* *"
    echo "nodupecheck $CHROOTEDSITEROOT/$SECTIONPATH/* "
    echo "creditcheck $CHROOTEDSITEROOT/$SECTIONPATH/* 0"
    echo "nostats $CHROOTEDSITEROOT/$SECTIONPATH/* *"
  fi
fi

if [ "$GLCONFADVICE" = "TRUE" ]; then
  echo "# Now for some advice how to hide your newly created folder for" > $TEMPSTORAGE/newaffil.$2
  echo "# everyone except $GROUPNAME." >> $TEMPSTORAGE/newaffil.$2
  echo "# We will presume that the group created in glftpd is" >> $TEMPSTORAGE/newaffil.$2
  echo "# named $GROUPNAME, just like the folder we just created." >> $TEMPSTORAGE/newaffil.$2
  echo "# If its not, change =$GROUPNAME below to whatever the group is called." >> $TEMPSTORAGE/newaffil.$2
  echo "#"  >> $TEMPSTORAGE/newaffil.$2
  echo "# Add this to start with:" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "privpath $CHROOTEDSITEROOT/$SECTIONPATH/$GROUPNAME  =$GROUPNAME !*" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "# If you also wish to hide the group folder, do this too." >> $TEMPSTORAGE/newaffil.$2
  echo "# Note, this has to be done BELOW the previous line." >> $TEMPSTORAGE/newaffil.$2
  echo "# If you have more privpaths to $CHROOTEDSITEROOT/$SECTIONPATH, " >> $TEMPSTORAGE/newaffil.$2
  echo "# it has to be below that one too." >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "privpath $CHROOTEDSITEROOT/$SECTIONPATH  =$GROUPNAME !*" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "# If you have other pre folders in $SECTIONPATH, it could look something" >> $TEMPSTORAGE/newaffil.$2
  echo "# like this:" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "## XXX Affiliated settings." >> $TEMPSTORAGE/newaffil.$2
  echo "privpath $CHROOTEDSITEROOT/$SECTIONPATH/$GROUPNAME  =$GROUPNAME !*" >> $TEMPSTORAGE/newaffil.$2
  echo "privpath $CHROOTEDSITEROOT/$SECTIONPATH/SomeOtherGroup  =SomeOtherGroup !*" >> $TEMPSTORAGE/newaffil.$2
  echo "privpath $CHROOTEDSITEROOT/$SECTIONPATH  =$GROUPNAME =SomeOtherGroup !*" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  if [ "$CREATESYMLINKS" = "TRUE" ]; then
    echo "# You may also wish to hide the symlinks folder." >> $TEMPSTORAGE/newaffil.$2
    echo "# As with above, put the group specific folders first, then" >> $TEMPSTORAGE/newaffil.$2
    echo "# the generic $SYMLINKPATH folder below those." >> $TEMPSTORAGE/newaffil.$2
    echo "" >> $TEMPSTORAGE/newaffil.$2
    echo "privpath $CHROOTEDSITEROOT/$SYMLINKPATH/$GROUPNAME  =$GROUPNAME !*" >> $TEMPSTORAGE/newaffil.$2
    echo "privpath $CHROOTEDSITEROOT/$SYMLINKPATH  =$GROUPNAME !*" >> $TEMPSTORAGE/newaffil.$2
    echo "" >> $TEMPSTORAGE/newaffil.$2
    echo "# Then, as you get more affils, add their name to the generic path. Like:" >> $TEMPSTORAGE/newaffil.$2
    echo "" >> $TEMPSTORAGE/newaffil.$2
    echo "## Generic $SYMLINKSPATH settings." >> $TEMPSTORAGE/newaffil.$2
    echo "privpath $CHROOTEDSITEROOT/$SYMLINKPATH/$GROUPNAME  =$GROUPNAME !*" >> $TEMPSTORAGE/newaffil.$2
    echo "privpath $CHROOTEDSITEROOT/$SYMLINKPATH/OtherGroup  =OtherGroup !*" >> $TEMPSTORAGE/newaffil.$2
    echo "privpath $CHROOTEDSITEROOT/$SYMLINKPATH  =$GROUPNAME =OtherGroup =!*" >> $TEMPSTORAGE/newaffil.$2
    echo "" >> $TEMPSTORAGE/newaffil.$2
  fi
  echo "# You would also hide them in 'site who' listing I guess." >> $TEMPSTORAGE/newaffil.$2
  echo "# Just hide everyone in the generic pre folder for that section." >> $TEMPSTORAGE/newaffil.$2
  echo "# Then you dont have to do it each time you get a new affil." >> $TEMPSTORAGE/newaffil.$2
  echo "# NOTE, if your site structure is similar for all sections, you can make this" >> $TEMPSTORAGE/newaffil.$2
  echo "# a bit easier. I mean, if you have /DIVX/GROUPS, /SVCD/GROUPS etc, do:" >> $TEMPSTORAGE/newaffil.$2
  echo "# instead of hideinwho /site/DIVX/GROUPS/* *" >> $TEMPSTORAGE/newaffil.$2
  echo "# do like    hideinwho /site/*/GROUPS/* *" >> $TEMPSTORAGE/newaffil.$2
  echo "# This works for every setting below here." >> $TEMPSTORAGE/newaffil.$2
  echo "# Otherwise, heres your hideinwho." >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "hideinwho $CHROOTEDSITEROOT/$SECTIONPATH/*  *" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "# Guess they should have leech there too, right?" >> $TEMPSTORAGE/newaffil.$2
  echo "# This will give everyone leech in groups folders, but since they only" >> $TEMPSTORAGE/newaffil.$2
  echo "# see their own folder, it does not matter." >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "creditloss 0 yes $CHROOTEDSITEROOT/$SECTIONPATH/* *" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "# Lets remove dupecheck too..." >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "nodupecheck $CHROOTEDSITEROOT/$SECTIONPATH/* " >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "# If your pre script gives credits and stats for preeing, affils should not get" >> $TEMPSTORAGE/newaffil.$2
  echo "# credits or stats when they upload (Usually the case). If so:" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "creditcheck  $CHROOTEDSITEROOT/$SECTIONPATH/* 0" >> $TEMPSTORAGE/newaffil.$2
  echo "nostats $CHROOTEDSITEROOT/$SECTIONPATH/* *" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2
  echo "# Thats about it. Dont forget to give the group access to the custom-pre command too." >> $TEMPSTORAGE/newaffil.$2
  echo "# If you wish to cut and paste later, this help file was written to $TEMPSTORAGE/newaffil.$2" >> $TEMPSTORAGE/newaffil.$2
  echo "" >> $TEMPSTORAGE/newaffil.$2

sleep 1
more $TEMPSTORAGE/newaffil.$2
fi

exit 0      
    

## To save HD space, remove everything below here, hehe.

For fun, this is what I had before for personal use. A bit shorter, yes? :)

if [ "$1" != "" -o "$2" != "" ]; then
    mkdir /glftpd/site/GROUPS/$1
    echo "Created shortcut folder /glftpd/site/GROUPS/$1"
    mkdir /glftpd/site/$2/GROUPS/$1
    echo "Created pre folder in $2"
    ln -d -s /site/$2/GROUPS/$1 /glftpd/site/GROUPS/$1/$2
    echo "Created symlink to section $2 in group folder $1"
    chmod 755 /glftpd/site/GROUPS/$1
    chmod 777 /glftpd/site/$2/GROUPS/$1
    echo "Setting folder permissions"
else
    echo "Usage: makeaffilsfolder.sh group section"
    echo "Only type one section at a time."
    echo "Valid sections are SVCD, DIVX, XXX, VCD, 0DAYS & ISO-UTILS"
    echo "(C) Turranius - 2001"
fi
